#
#  epr_tools.py
#  EPR Power Saturation Analysis
#
#  Created by Grischa Meyer on 7.9.05.
#  Copyright (c) 2007 Grischa Meyer. All rights reserved.
#

import struct

def loadDataFileToArray(filename):
    input = file(filename).read()
    numfloats = len(input)/4
    return struct.unpack( '<' + 'f' * numfloats, input )


def readParFile(filename):
	linearray = file(filename).read().split('\r')
	params = {}
	for p in linearray[0:-1]:
		q = p.split()
		params[q[0]] = q[1]
	return params


def getPowerSpecData( datafilename, parfilename):
	data = loadDataFileToArray( datafilename )
	params = readParFile( parfilename )
	specs = []
	for i in range(int(params['SSY'])):
		specs.append(data[i*int(params['SSX']):(i+1)*int(params['SSX'])])
	return specs


def maxMinDist(data):
	result = []
	for d in data:
		result.append(max(d) - min(d))
	return result

def powerArray( basename ):
    params = readParFile( basename +  ".par" )
    initialAttenuation = float(params['MPD'])
    initialPower = float(params['MP'])
    totalPower = initialPower/(10**(-initialAttenuation/10.0))
    attStep = float(params['MPS'])
    finalAttenuation = initialAttenuation + ( int(params['SSY']) - 1 ) * attStep
    powers = []
    for att in range( int(initialAttenuation), int(finalAttenuation) + 1, int(attStep)):
        powers.append( 10**( -att / 10.0 ) * totalPower)
    return powers


###
# the following is a function to do analysis from the python shell
###
from r_interface import *
from rpy import *
from Analysis import *

### doItAll arguments:
# name is directory name of data file;
# number is filebasename of data file, eg. 44C, or 46C-LPC;
# exp is type of experiment, N2, O2, Ni;
# a, h and p are fitting parameters
def doItAll( name, number, exp, a, h, p): 
    initRGraphics("x11()")
    filePath = "/Users/grischa/Documents/Work/Experiments/MscL/EPR/Difficults/" + name + "/"
    fileBasename = filePath + number + "-" + exp
    powers = powerArray(fileBasename)
    sqpow = r.sqrt( powers )
    fit = Analysis( fileBasename, sqpow, a, h, p )
    fit.plot()
    print fit.result()
    return 1
